find_border_width: Find buffer width that produces target area per side

View source: R/aoe_border.R

find_border_widthR Documentation

Find buffer width that produces target area per side

Description

Find buffer width that produces target area per side

Usage

find_border_width(border_geom, target_area, mask_geom, crs)

Arguments

border_geom

Border line geometry (sfc)

target_area

Target area for each side

mask_geom

Optional mask geometry

crs

CRS of the geometries

Value

Buffer width


areaOfEffect documentation built on Feb. 7, 2026, 1:08 a.m.