get_country: Get Country Polygon by Name or ISO Code

View source: R/data.R

get_countryR Documentation

Get Country Polygon by Name or ISO Code

Description

Quick accessor for country polygons from the bundled dataset.

Usage

get_country(x)

Arguments

x

Country name, ISO2 code, or ISO3 code (case-insensitive)

Value

An sf object with the country polygon, or error if not found.

Examples

get_country("Belgium")
get_country("BE")
get_country("BEL")


areaOfEffect documentation built on Feb. 7, 2026, 1:08 a.m.