land: Global Land Mask

landR Documentation

Global Land Mask

Description

An sf object containing the global land polygon from Natural Earth (1:50m scale). Used for masking area of effect computations to exclude ocean areas.

Usage

land

Format

An sf data frame with 1 row:

name

Description ("Global Land")

geometry

Land multipolygon in WGS84 (EPSG:4326)

Natural Earth https://www.naturalearthdata.com/

Examples

# Use as mask to exclude sea

dummy <- sf::st_as_sf(
  data.frame(id = 1),
  geometry = sf::st_sfc(sf::st_point(c(14.5, 47.5))),
  crs = 4326
)
result <- aoe(dummy, "AT", mask = land)



areaOfEffect documentation built on Feb. 7, 2026, 1:08 a.m.