| get_country | R Documentation |
Quick accessor for country polygons from the bundled dataset.
get_country(x)
x |
Country name, ISO2 code, or ISO3 code (case-insensitive) |
An sf object with the country polygon, or error if not found.
get_country("Belgium")
get_country("BE")
get_country("BEL")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.