powered by
Quick accessor for country polygons from the bundled dataset.
get_country(x)
An sf object with the country polygon, or error if not found.
sf
Country name, ISO2 code, or ISO3 code (case-insensitive)
get_country("Belgium") get_country("BE") get_country("BEL")
Run the code above in your browser using DataLab