| land | R Documentation |
An sf object containing the global land polygon from Natural Earth (1:50m scale).
Used for masking area of effect computations to exclude ocean areas.
land
An sf data frame with 1 row:
Description ("Global Land")
Land multipolygon in WGS84 (EPSG:4326)
Natural Earth https://www.naturalearthdata.com/
# Use as mask to exclude sea
dummy <- sf::st_as_sf(
data.frame(id = 1),
geometry = sf::st_sfc(sf::st_point(c(14.5, 47.5))),
crs = 4326
)
result <- aoe(dummy, "AT", mask = land)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.